function analyze_data( cohort, hfoAlgo )
  %% function analyze_data( cohort, hfoAlgo )
  % function analyze_data()
  %
  % Analyzes temporal variations using blind source separation.  Note:
  % the process is stochatic. Results are saved in the subdirectory
  % 'data'.
  %
  % The no-input, no-output option loops over all possible cohort,
  % hfoAlgo possibilities.  Possible values for cohort are
  % 'Mayo','Control','UMHS-2hr', or 'UMHS-NREM'. Possible values for
  % hfoAlgo are 'qHFO_v2.2', 'qHFO_v2.2_FR_200', 'other-HIL'.
  %
  % Created in 2018 by S. Gliske (sgliske@umich.edu)
  % Released under the CC-BY-NC-4.0 License
  % http://creativecommons.org/licenses/by-nc/4.0/
  %

  %% parameters
  MIN_NUM_EPOCHS = 6;
  NUM_REPS       = 10;

  %% ignore these warnings during blind source separation
  S1 = warning('off', 'stats:nnmf:LowRank' );
  S2 = warning('off', 'MATLAB:singularMatrix' );
  S3 = warning('off', 'MATLAB:rankDeficientMatrix' );

  validCohorts = {'Mayo','Control','UMHS-2hr','UMHS-NREM'};
  validHfoAlgos = {'qHFO_v2.2', 'qHFO_v2.2_FR_200', 'other-HIL'};

  %% check if input arguments
  if( nargin < 1 )
    for i=1:length(validCohorts)
      for j=1:length(validHfoAlgos)
        fprintf('\n---- %s %s ----\n\n', validCohorts{i}, validHfoAlgos{j} );
        ticA = tic;
        analyze_data( validCohorts{i}, validHfoAlgos{j} );
        toc(ticA);
      end
    end
  else
    %% check input
    assert(any(strcmp(cohort, validCohorts)), 'Invalid cohort');
    assert(any(strcmp(hfoAlgo, validHfoAlgos)), 'Invalid hfoAlgo');

    %% load data
    load(['data/' cohort '.' hfoAlgo '.inputData.mat'], 'data');

    %% loop over patients
    results = repmat(struct('counts',[],'rate',[],'bss',[]),length(data),1);
    for k=1:length(data)
      fprintf('On %d of %d: %s\n', k, length(data), data(k).dbKey );

      %% compute HFO rate
      counts = zeros( data(k).nChan, length(data(k).validHours) );
      if( ~isempty(data(k).hfos.epochNum) )
        assert(  length(data(k).validHours) >= max(data(k).hfos.epochNum) )

        temp = accumarray( [data(k).hfos.chanIdx, data(k).hfos.epochNum], 1 );
        counts(1:size(temp,1),1:size(temp,2)) = temp;
        results(k).counts = counts;
        results(k).rate = counts ./ repmat( data(k).validHours, data(k).nChan, 1 ) / 60;
      else
        fprintf('\tNo HFOs\n');
        results(k).counts = [];
        results(k).rate = [];
        results(k).bss = [];
        continue
      end

      if( strcmp( cohort, 'UMHS-2hr' ) )
        %% classify the rate per each segment (night) of data

        uSegID = unique(data(k).segID);
        %rateClass = cell(length(uSegID),NUM_REPS);
        results(k).bss = cell(max(uSegID),NUM_REPS);
        for j=uSegID
          I = data(k).segID == j;
          for i=1:NUM_REPS
            results(k).bss{j,i} = blind_source_separation( results(k).rate(:,I) );
          end
        end
      else
        %% classify the rate using all data meeting previous selection requirements
        results(k).bss = cell(1,NUM_REPS);
        for i=1:NUM_REPS
            results(k).bss{i} = blind_source_separation( results(k).rate );
        end
        results(k).bss = cell2mat( results(k).bss );
      end

      %% scan over multiple starting times
      if( strcmp(cohort, 'UMHS-NREM') && length(data(k).startHour) >= MIN_NUM_EPOCHS )
        fprintf('\tStarting scan over amount of data to categorize\n');
        
        %% prep
        epEndTime = data(k).startHour + 10/60;
        %nEpochs   = length(epEndTime);
        
        %% find break points
        breakHere = unique(ceil(epEndTime));
        breakHere = arrayfun( @(x) find(epEndTime < x, 1, 'last'), breakHere );
        breakHere = breakHere( breakHere >= MIN_NUM_EPOCHS );
        nPoints = length(breakHere);
        
        %% more preparation
        tempResults = cell(nPoints,1);
        rate = results(k).rate;
        parfor j=1:nPoints
          fprintf('\t\tPoint %d of %d\n', j, nPoints );
          tempResults{j} = cell(1,NUM_REPS);
          
          for kk=1:NUM_REPS
            tempResults{j}{kk} = blind_source_separation( rate(:,1:breakHere(j)) ); %#ok<PFBNS>
          end
          tempResults{j} = cell2mat( tempResults{j} );
        end
        
        % copy out results
        results(k).scan.catResults = tempResults;
        results(k).scan.allEpTimes = ceil(epEndTime(breakHere));
      end
    end
    
    %% save
    save(['data/' cohort '.' hfoAlgo '.results.mat'], 'results');
    
    %% reset warnings
    warning(S1);
    warning(S2);
    warning(S3);
    
  end
  
