function results = blind_source_separation( rate )
%% function results = blind_source_separation( rate )
%
%  Classify the variability in the rate
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

%% Check selection requirements: at least one channel with an HFO rate > 0.5 / min
if( numel(rate) < 1 || ~sum(rate(:)) || max(rate(:)) < 0.5)
    results.K = 0;
    return;
end

%% throw out empty channels
I = mean(rate,2) > 0;
rate = rate(I,:);

%% prep
[nChan, nEp] = size(rate);

%% Set starting K

K = min(size(rate));
K = min(K, 12);

%% factorize

maxC = 1;
while( maxC > 0.3 )

   [W,H] = robust_nnmf( rate, K );

   k = 0;
   while(size(W,2) < K && k < 1000 )
       fprintf('********** repeating (%d, %d0) **********', K, k );
     [W,H] = robust_nnmf( rate, K );
     k = k + 1;
   end

   if( ~all(isfinite(W(:))) || ~all(isfinite(H(:))) )
       if( K > 1 )
          K = K - 1;
       end
       continue;
   end
   
   if( size(W,2) < K )
     fprintf('Warning: failed to converge with K = %d\n', K );
     K = size(W,2);
     continue;
   end
   
   C = corr(H', 'type', 'spearman');
   C( eye(size(C)) == 1 ) = 0;
   maxC1 = max(C(:));  % removed abs 5/26/16

   C = corr(W, 'type', 'spearman');
   C( eye(size(C)) == 1 ) = 0;
   maxC2 = max(C(:));  % removed abs 5/26/16
   
   maxC = max(maxC1, maxC2);

   %fprintf('K = %d, Correlations: %.3f. %.3f\n', K, maxC1, maxC2 );
   K = K - 1;
end
K = size(W,2);

%% shift normalization so that H can be interpreted as an effective HFO rate

mu = sum(W,1) / nChan * K;   % matches average
W = W*diag(1./mu);
H = diag(mu) * H;

%% copy to output

results.W = W;
results.H = H;
results.isConsist = mean(H > repmat( mean(H,2), 1, nEp ),2) > 0.4 & mean(H==0,2) < 0.05;
results.K = K;

if( K == 1 )
    if( results.isConsist )
        results.label = 'a';
    else
        results.label = 'b';
    end
else
    results.label = 'c';
end


end
