function asym = compute_asym( hfoAlgo, outcome, ROI )
  %% function asym = compute_asym( hfoAlgo, outcome, ROI )
  %
  % Compute the asymmetry for a given hfoAlgorigm with respect to a
  % given region of interest (ROI), with the optional cut on surgical
  % outcome. Results for all cohorts are provided.
  %
  % Valid HFO algorithms include hfoAlgo is 'qHFO_v2.2',
  % 'qHFO_v2.2_FR_200', 'other-HIL'.
  %
  % Valid outcome options are:
  % - [] for no cut
  % -  1 for ILAE Class I
  % -  2 for ILAE Class >I
  % -  3 for unknown ILAE class or not applicable
  %
  % Valid ROI values are 'SOZ' and 'RV' for the seizure onset zone and
  % resected volume, respectively.
  %
  % Created in 2017 by S. Gliske (sgliske@umich.edu)
  % Released under the CC-BY-NC-4.0 License
  % http://creativecommons.org/licenses/by-nc/4.0/

THRES = 5; % per 10 minutes

%% check input
if( ~any(strcmp( hfoAlgo, {'qHFO_v2.2', 'qHFO_v2.2_FR_200', 'other-HIL'} ) ) )
  error('compute_asym:input_options','Invalid HFO algorithm');
end

if( ~isempty(outcome) && ~any( outcome == 1:3 ) )
  error('compute_asym:input_options','Invalid outcome category');
end

if( ~any(strcmp( ROI, {'SOZ', 'RV'} ) ) )
  error('compute_asym:input_options','Invalid region of interest (ROI)');
end

%% Loop over cohorts
names = {'UM_NREM', 'UM_2hr', 'Mayo'};
clear asym
for k=1:3

  %% load data
  if( k==1 )
    %% UM NREM
    f = load(['data/UMHS-NREM.' hfoAlgo '.inputData.mat']);
    g = load(['data/UMHS-NREM.' hfoAlgo '.results.mat']);
  elseif( k==2 )
    %% UM NREM
    f = load(['data/UMHS-2hr.' hfoAlgo '.inputData.mat']);
    g = load(['data/UMHS-2hr.' hfoAlgo '.results.mat']);
  else
    f = load(['data/Mayo.' hfoAlgo '.inputData.mat']);
    g = load(['data/Mayo.' hfoAlgo '.results.mat']);
  end

  %% prep for loop
  asym.(names{k}).oneEp = cell(length(g.results),1);
  asym.(names{k}).full  = NaN(length(g.results),1);

  %% loop over all subjects
  for i=1:length(g.results)
    %% prep structure
    r = f.data(i);
    r.bss = g.results(i).bss;
    r.counts = g.results(i).counts;

    proceed = ~isempty(r) && ~isempty(r.bss) && all(isfinite(r.(ROI)));

    %% cut to just the first night of data if doing UM 2hr
    if( k==2 )  
      kk = find(any(cellfun( @(x) isfield( x, 'label' ), r.bss ),2),1);
      if( ~numel(kk) )
        proceed = false;  % no data
      else
        ii = (kk-1)*12 + 1;
        jj = kk*12;
        r.counts = r.counts(:,ii:jj);  % restricting to just the first night with data
      end
    elseif( proceed )
      %proceed = any(any(cellfun( @(x) isfield( x, 'label' ), r.bss ),2));  %% make sure there is at least some valid data
      proceed = isfield( r.bss, 'label' );
    end

    if( proceed  && ~isempty(outcome) )
      if( outcome == 1 )
        proceed = r.outcomeCategory == 1; % good outcome == 1 in the inputData file
      elseif( outcome == 2 )
        proceed = r.outcomeCategory == 3;  % bad outcome == 3 in the inputData file
      else % must be 3, as already checked outcome is empty or one of 1:3
        proceed = r.outcomeCategory == 2 || r.outcomeCategory == 4;  % unknown outcome == 2, no resection == 4 in the inputData file
      end
    end

    if( proceed )

      %% make sure ROI is not bigger than counts (needed as one patient is missing channels)
      if( size(r.counts,1) < length(r.(ROI)) )
        r.(ROI) = r.(ROI)(1:size(r.counts,1));
      end

      rIn = mean(r.counts(r.(ROI),:),1);
      rOut = mean(r.counts(~r.(ROI),:),1);
      valid = max(r.counts,[],1) >= THRES; % 5 per 10 minutes = 0.5 / min
      asym.(names{k}).oneEp{i} = (rIn(valid)-rOut(valid))./(rIn(valid)+rOut(valid));

      rIn = mean(rIn);
      rOut = mean(rOut);
      valid = max(r.counts(:)) >= THRES;  % 5 per 10 minutes = 0.5 / min

      if( valid )
        asym.(names{k}).full(i) = (rIn-rOut)./(rIn+rOut);
      end
    end
  end

end

end

