function makeRateHeatMap( rate, order, cases, hour, segID, nightID, nightLabel )
%% function makeRateHeatMap( rate, order, cases, hour, segID, nightID, nightLabel )
%   
%  Make heat map for set of "rates"
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

%% prep

[nChan, nEps] = size(rate);
%fprintf('Head map of size %d x %d\n', nChan, nEps );

%% figure out RV and SOZ from cases

haveRV = cases{5}.haveRV;
haveSOZ = cases{5}.haveSOZ;

SOZ = NaN;
if( haveSOZ )
    SOZ = union( cases{1}, cases{2} );
end

RV = NaN;
if( haveRV )
    RV = union( cases{2}, cases{3} );
end

%% set up shifts

if( all(isfinite(nightID)) )
    yShift = max(ceil(0.075*nChan),3);
else
    yShift = 1;
end

if( haveRV || haveSOZ )
    xShift = ceil(0.15*nEps);
else
    xShift = 1;
end

temp = NaN(size(rate) + [yShift xShift]);
temp(1:nChan,1:nEps) = rate( flip(order), : );

%% plot heat map

pcolor( temp )
shading flat

%% plot gaps and prepare x-tick labels

if( ~isempty(hour) )
    times = arrayfun( @(x,y) sprintf('%d:%02d', x, y), floor(hour),round((hour-floor(hour))*60), 'uniformoutput', false );
    
    xTick = 1;
    xTickLabel = times(1);
    
    for i=2:nEps
        if( segID(i-1) ~= segID(i) )
            line( i*[1 1], [1 nChan+1], 'color', 'w' );
            xTick = [xTick i]; %#ok<*AGROW>
            xTickLabel = [xTickLabel times(i)];
        end
        
        %if( i - xTick(end) >= 3 )
        %    xTick = [xTick i]; %#ok<*AGROW>
        %    xTickLabel = [xTickLabel times(i)];
        %end
    end
    xTick = xTick + nEps*0.015;
    
    I = find(diff(xTick) > 0.01 * nEps);
    if( any(I) )
        if(~I(1))
            I = [1 I];
        end
        xTick = xTick(I);
        xTickLabel = xTickLabel(I);
    end

else
    xTick = (1:nEps) + 0.5;
    xTickLabel = arrayfun(@(x) sprintf('%d', floor(x)), xTick, 'uniformoutput', false );
end

if( nEps > 3 && nEps < 16 )
    xTick = 1:3:nEps;
    xTickLabel = arrayfun( @(x) sprintf('%d:%02d', floor(x), mod( x*60, 60 ) ), (xTick-1)*1/6+1, 'uniformOutput', false );
end


%% plot days

if( all(isfinite(nightID)) )
    y1 = nChan + 1 + 0.05*yShift;
    y2 = nChan + 1 + 0.95*yShift;
    
    lastMark = 1;
    for i=2:nEps
        if( nightID(i-1) ~= nightID(i) )
            line( i*[1 1], [y1 y2], 'color', 'k', 'linewidth', 2 )
            
            text( (lastMark+i)/2, (y1+y2)/2, sprintf('%s %d', nightLabel, nightID(i-1) ), ...
                'horizontalalign', 'center', 'verticalalign', 'middle', 'fontsize', 12 );
            lastMark = i;
        end
    end
    line( [1 1], [y1 y2], 'color', 'k', 'linewidth', 2 )
    line( [1 1], [nChan+1 y1], 'color', 'w', 'linewidth', 2 )
    line( nEps*[1 1]+1, [y1 y2], 'color', 'k', 'linewidth', 2 )
    
    text( (lastMark+nEps)/2, (y1+y2)/2, sprintf('%s %d', nightLabel, nightID(i-1) ), ...
        'horizontalalign', 'center', 'verticalalign', 'middle', 'fontsize', 12 );
end

%%
L = [length(order), length(order) - cumsum(cellfun( @length, cases ))];

if( 0 )
%if( length(RV) == length(SOZ) && all( RV == SOZ ) )
%    error('not yet programmed');
else
    doIt = [ haveSOZ, haveRV ];
    labels = { 'SOZ', 'RV' };
    color = { 'k', 'r' };
    
    for i=1:2
        if( doIt(i) )
            y1 = 1+L(i);
            y3 = 1+L(i+2);
            y2 = (y1 + y3)/2;

            x1 = nEps + 1 + 0.1*xShift;
            x2 = x1 + i*0.08*xShift + 0.28;
            x3 = max(x1 + 0.35*xShift, x2+0.13*xShift);
            
            line( [x1 x2], [ y1 y1-1 ], 'color', color{i} );
            line( [x2 x3], y2*[ 1 1 ], 'color', color{i} );
            line( [x1 x2], [ y3 y3+1 ], 'color', color{i} );
            line( x2*[1 1], [y1-1 y3+1 ], 'color', color{i} );
            
            line( [1 x1], y1*[ 1 1 ], 'color', color{i} );
            line( [1 x1], y3*[ 1 1 ], 'color', color{i} );
            
            %if( length(RV) == length(SOZ) && all( RV == SOZ ) )
            %    this_text = 'SOZ & RV';
            %else
                this_text = labels{i};
            %end
            
            text( x3+0.05*xShift, y2, this_text, 'verticalalignment', 'middle', 'horizontalalignment', 'left', 'fontsize', 18, 'color', color{i} );
        end
    end
end


%% make pretty

set( gca, 'TickLength', [0.005 0], 'Box', 'off' );

set( gca, 'XTick', xTick, 'XTickLabel', xTickLabel, 'fontsize', 14 );

if( ~isempty(hour) )
    h = xlabel('Time of Day');
    if( strcmp( h.Units, 'normalized' ) )
        set(h, 'position', [0.5 -0.17 0] );
    end

    if( isempty(which('xticklabel_rotate')) )
        addpath('/home/sgliske/neuro/2015/matlab-scripts/xticklabel_rotate');
    end
    xticklabel_rotate();

else
    h = xlabel('Chan. Group');
    %set(h, 'position', [0.5 -0.17 0] );
end

yTick = get( gca, 'YTick');
I = yTick <= nChan;
set( gca, 'YTick', yTick(I) );

h = ylabel('Channel Enumeration');
set(h, 'position', [-0.035 0.5 0] );

set(gca, 'fontsize', 18)

%% colorbar

h = colorbar;
xlabel(h,'HFOs / min', 'fontsize', 18)


end

