function plot_asyms( doNREM, outcome, ROI )
%% function asym = plot_asyms( doNREM, outcome, ROI )
%
% Plot the asymmetries for a multiple hfoAlgorigms with respect to a
% given region of interest (ROI), with the optional cut on surgical
% outcome. Results for all cohorts are provided.  doNREM is a logical
% parameter setting whether to use all NREM data for the UM Cohort or
% whether to just use the 2 hr data from 1-3 AM.
%
% Valid outcome options are:
% - [] for no cut
% -  1 for ILAE Class I
% -  2 for ILAE Class >I
% -  3 for unknown ILAE class or not applicable
%
% Valid ROI values are 'SOZ' and 'RV' for the seizure onset zone and
% resected volume, respectively.
%
% Created in 2018 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

if( strcmp( ROI, 'RV' ) )
  height = 400;
  k1 = 2;
  nplots = 1;
else
  height = 800;
  k1 = 1;
  nplots = 2;
end

set(gcf, 'Renderer', 'painters', ...
  'InvertHardcopy','on',...
  'Position',[0 0 1500 height]+50,...
  'PaperPositionMode','auto');
clf

%%
hfoAlgoKeys = {'qHFO_v2.2', 'qHFO_v2.2_FR_200', 'other-HIL' };
hfoAlgoNames = {'qHFO', 'qHFO-FR', 'Hil' };
if( doNREM )
  cohortNames = {'Mayo','UM_NREM'};
else
  cohortNames = {'Mayo','UM_2hr'};
end

green  = [127,201,127]/255;
orange = [253,192,134]/255;
blue   = [56,108,176]/255;

%%
gray = 0.9*[1 1 1];

clear hL
clf
fprintf('%8s %17s | %15s %15s | %15s %15s | %20s\n', 'cohort', 'hfo algo.', 'median (10 min)', 'p-value (10min)', 'median (ave)', 'p-value (ave)', 'p-value 10-min vs. ave' );
for k=k1:2
  cohort = cohortNames{k};
  
  if( k == 1 )
    colors = {blue, gray};
  else
    colors = {green, orange};
  end
  
  for i=1:3
    if( strcmp( ROI, 'RV' ) )
      n = i;
    else
      n = (k-1)*3 + i;
    end
    subplot(nplots,3,n);
    asym = compute_asym( hfoAlgoKeys{i}, outcome, ROI );
    
    a = [asym.(cohort).oneEp{:}];
    b = asym.(cohort).full;
    
    a = a(isfinite(a));
    b = b(isfinite(b));
    
    if( isempty(a) && isempty(b) )
      continue
    end
    
    h = gbar2( a, b, 10, colors, 1, [-1 1] );
    for j=1:2
      h(j).EdgeColor = 'k';
    end
    ylim([0 0.65]);
    
    xlabel(['Asymmetry (' hfoAlgoNames{i} ')']);
    ylabel('Fraction of Data Segments');
    set(gca,'fontsize',16)
    
    fprintf('%8s %17s | %15.3f %15.4g | %15.3f %15.4g | %20.4g\n', cohort, hfoAlgoKeys{i}, median(a), signrank( a, 0.0, 'tail', 'right' ), median(b), signrank( b, 0.0, 'tail', 'right' ), ranksum( a, b ) );
    
    % letter
    pos = get(gca,'Position');
    addLetter( char('A' + (k-1)*3 + i-1), pos(1)-0.06, pos(2)+pos(4)-0.05 );
    
    % legend
    hL = legend({sprintf('Individual 10-min epochs (N=%d)', length(a)),sprintf('Time-average per Subject (N=%d)', length(b))}, 'fontsize', 12);
    a = gca;
    hL.Position(1) = a.Position(1)+(a.Position(3)-hL.Position(3))/2;
    hL.Position(2) = a.Position(2)+a.Position(4)-hL.Position(4) - 0.02;
    a.Box = 'off';
    ylim([0 0.55])

  end
end

%%

oKey = {'best','poor','unknown','ignored'};
if( isempty(outcome) )
  outcome = 4;
end

if(isempty(dir('plots')))
  mkdir('./plots');
end

if( doNREM )
  print(['plots/asym_plot.' ROI '.' oKey{outcome} '.eps'], '-depsc')
else
  print(['plots/asym_plot.' ROI '.2hr.' oKey{outcome} '.eps'], '-depsc')
end

