function plot_categories( hfoAlgo )
%% function plot_categories( hfoAlgo )
%
% Plot the categories of HFO temporal variability per cohort for a given
% hfo algorithm.  Possible values for hfoAlgo are 'qHFO_v2.2',
% 'qHFO_v2.2_FR_200', and 'other-HIL'.
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

%% gather data

cohort = {'Mayo', 'Control', 'UMHS-2hr', 'UMHS-NREM' };
cohortKey = {'Mayo','Control','UM_2hr','UM'};

for k=1:length(cohort)
  %%
  f = load(['data/' cohort{k} '.' hfoAlgo '.results.mat']);

  nSub = length(f.results);
  if( k==3 )
    L = [];
    w = [];
  else
    L = zeros(1,nSub);
    w = 1;
  end
  
  for i=1:nSub
    r = f.results(i);
    
    if( ~isempty( r ) )
      if( k==3 ) % need to combine the answer for multiple nights
        n1 = size( r.bss, 1 );
        K = zeros(size(r.bss));
        for jj=1:size(r.bss,1)
          for kk=1:size(r.bss,2)
            if( ~isempty(r.bss{jj,kk} ) )
              K(jj,kk) = r.bss{jj,kk}.K;
            end
          end
        end
        I = K(:,1) > 0;
        temp = cell2mat( r.bss(I,:) );
        
        [n2,m2] = size(temp);
        
        labels = [];
        if( n2 > 0 )
          labels = mode(reshape([temp.label], n2, m2), 2);
        end
        
        if( n2 ~= n1 )
          labels = [labels; 'd'*ones(n1-n2,1)];
        end
        %fprintf('Subject %d, labels %s\n', i, labels );
        
        labels = labels - 'a' + 1;
        L = [L; labels]; %#ok<*AGROW>
        w = [w; ones(n1,1)/n1 ];
        assert( length(labels) == n1 );
        
        %if( n2 == n1 && n1 > 0 && all( labels == labels(1) ) )
        %  fprintf('\tSubject %d has all nights consistent\n', i);
        %end
        
      elseif( isempty(r.bss) )
        L(i) = 4;
      elseif( r.bss(1).K > 0 )
        L(i) = -mode(-[r.bss.label]) - 'a' + 1;
      else
        L(i) = 4;
      end
    else
      fprintf('WARNING: no results for index %d\n', i);
    end
  end

  %% ignore empties
  I = L>0;
  L = L(I);
  if( numel(w) > 1 )
    w = w(I);
  end
  
  %% count
  temp = accumarray(L(:), w(:));
  counts.(cohortKey{k}) = zeros(4,1);
  counts.(cohortKey{k})(1:length(temp)) = temp;

  %% display
  fprintf('%16s: ', cohort{k});
  for i=1:4
    fprintf('%4.1f (%4.1f +/- %4.1f)%% ', counts.(cohortKey{k})(i), counts.(cohortKey{k})(i)/sum(counts.(cohortKey{k}))*100, sqrt(counts.(cohortKey{k})(i))/sum(counts.(cohortKey{k}))*100 );
  end
  fprintf('\n');
  
end

%% display Mayo + UM-NREM
fprintf('%16s: ', 'Mayo + UMHS-NREM');
temp_counts = counts.Mayo + counts.UM;
for i=1:4
  fprintf('%4.1f (%4.1f +/- %4.1f)%% ', temp_counts(i), temp_counts(i)/sum(temp_counts)*100, sqrt(temp_counts(i))/sum(temp_counts)*100  );
end
fprintf('\n');

%%

set(gcf, 'Renderer', 'painters', ...
    'InvertHardcopy','on',...
    'Position',[0 0 1500 300]+50,...
    'PaperPositionMode','auto');
clf

%%

order = {'Mayo', 'Control', 'UM_2hr', 'UM' };
allCounts = zeros(4,4);
fracs = zeros(4,4);
sigma   = zeros(4,4);
for i=1:4
    allCounts(:,i) = counts.( order{i} );
    fracs(:,i) = allCounts(:,i) / sum(allCounts(:,i))*100;
    sigma(:,i) = sqrt(allCounts(:,i)) / sum(allCounts(:,i))*100;  % VARIANCE
end

allCounts = allCounts';
fracs = fracs';
sigma = sigma';
h1 = bar(fracs);

green  = [127,201,127]/255;
purple = [190,174,212]/255;
orange = [253,192,134]/255;
yellow = [255,255,153]/255;
blue   = [56,108,176]/255;

colors = {blue, purple, yellow, green};

for i=1:4
    h1(i).FaceColor = colors{i};
end

cohortNames = {'Mayo (1-3 AM)', 'Controls (1-3 AM)', 'UM (1-3 AM)', 'UM (NREM sleep)' };
groupNames = {'(a) One Src.', '(b) One Src. on/off', '(c) Many srcs.', '(d) Few HFOs'};

%%
hold on
for i=1:4
  h2 = errorbar( (1:4) + 0.18*(i-2.5), fracs(:,i), sigma(:,i), 'k' );
  %h2(1).Color = colors{i};
  h2(1).Marker = 'none';
  h2(1).LineStyle = 'none';
end
hold off

hLegend = legend(h1, groupNames, 'fontsize', 18, 'location', 'NorthWest');
hLegend.Position(1) = 0.15;

% make pretty

set( gca, 'fontsize', 18 );
set( gca, 'xTickLabel', cohortNames, 'fontsize', 18);

ylabel( 'Percentage of subjects' )
xlabel( 'Cohort', 'fontsize', 24 );
ylim([0 95]);

a = [cellstr(num2str(get(gca,'ytick')'))];
pct = char(ones(size(a,1),1)*'%');
new_yticks = [char(a),pct];
set(gca,'yticklabel',new_yticks)

set( gca, 'box', 'off' );

print(['plots/categories.' hfoAlgo '.eps'], '-depsc');

 
%% 

fprintf('\np-values for all that are not (d) are (a)\n');

allCounts(end+1,:) = allCounts(1,:) + allCounts(4,:);
a = allCounts(:,1);
not_d = sum(allCounts(:,1:3),2);
chisq = (a-not_d).^2 ./ not_d;

cohort{end+1} = 'Mayo + UMHS-NREM';
for i=1:5
   fprintf('\t%16s: %g\n', cohort{i}, 1-chi2cdf( chisq(i), 1 ) );
end

