function plot_factorization( cohort, dbKey, hfoAlgo, thres )
%% function plot_factorization( dbKey )
%
% Plot the non-negative matrix factorization of HFO rates.
%
% Valid cohort values: 'Mayo','Control', 'UMHS-2hr', or 'UMHS-NREM'
%
% Valid dbKey values: either 'all' (to loop over all subjects in the
% cohort) or a dbKey value matching one of the a database identifier keys
% as stored in the input file.
%
% Possible values for hfoAlgo are 'qHFO_v2.2', 'qHFO_v2.2_FR_200',
% 'other-HIL'.
% 
% Threshold is used for determining which channels are above a certain
% value, i.e., for identifying which channels should have a white star in
% Fig. 3.
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

if( nargin < 3 )
  thres = [];
end

if( strcmp(dbKey, 'all') )
   %% loop over all dbKeys
    f = load(['data/' cohort '.' hfoAlgo '.inputData.mat']);
    for i=1:length(f.data)
        fprintf('--- %s ---\n', f.data(i).dbKey );
        plot_factorization( cohort, f.data(i).dbKey, hfoAlgo );
    end
    
else % plot results for just one subject
  
    %% find the index for the dbKey
    if( length(dbKey) ~= 9 )
        error( 'plot_factorization:input', 'dbKey must have length 9. Invalid dbKey: %s', dbKey );
    end
    
    f = load(['data/' cohort '.' hfoAlgo '.inputData.mat']);
    idx = find(strcmp(dbKey, {f.data.dbKey}));
    if( isempty(idx) )
        error( 'plot_factorization:input', 'Unknown subject: %s', dbKey );
    elseif( length(idx) > 1 )
        error( 'plot_factorization:input', 'Multiple subjects: %s', dbKey );
    end
    
    %% load results
    g = load(['data/' cohort '.' hfoAlgo '.results.mat']);
    r = f.data(idx);
    r.rate = g.results(idx).rate;
    r.bss = g.results(idx).bss;

    %% check
    if( sum(r.rate(:)) == 0 )
      fprintf('\tNo HFOs at all\n');
      return
    end
    
    %% clear
    clear f
    clear g
    
    %% copy some data
    
    hour = mod( r.startHour, 24 );
    segID = r.segID;
    
    if( strcmp(cohort(1:4), 'UMHS') )
      nightID = floor( r.startHour / 24 );  % go by calender day, not lay-file day
      nightLabel = 'day';
    else
      nightID = NaN;
      nightLabel = '';
    end
    
    SOZ = NaN;
    RV = NaN;
    
    if( all(isfinite(r.SOZ))&& ~isempty(r.SOZ))
      SOZ = r.SOZ;
    end
    if( all(isfinite(r.RV)) && ~isempty(r.RV) )
      RV  = r.RV;
    end

    [nChan, nEps] = size(r.rate);
    doWide = nEps > 20;
    
    %% prep figure
    
    set(gcf, 'Renderer', 'painters', ...
        'InvertHardcopy','on',...
        'PaperPositionMode','auto');
    if( doWide )
        set( gcf, 'Position', [0 0 1500 900]+50 );
    else
        set( gcf, 'Position', [0 0 900 900]+50 );
    end
    clf
    
    %% pick which one of the factorizations to use
    
    if( all(r.bss(1).K == 0) )
        fprintf('\tNo valid factorizations\n');
        return
    end
    category = [r.bss.label];
    fprintf('\tCategories: %s\n', category )
    
    k = find( category == mode(category), 1 );
    fprintf('\tUsing #%d: %c\n', k, category(k) );
    
    %% load W, H
    
    W = r.bss(k).W;
    H = r.bss(k).H;
    K = r.bss(k).K;
    
    if( size(W,1) < nChan )
        temp = zeros( nChan, K );
        
        I = mean(r.rate,2) > 0;
        temp(I,:) = W;
        W = temp;
    end
    
    [order, cases] = determineOrder( r.rate, SOZ, RV );
    
    %fprintf('Note sum of W: [ %s]\n', sprintf('%7.3f ', sum(W)) );
    
    %% rate plot
    clf
    if( doWide )
        ax(1) = axes( 'position', [0.07 0.59 0.9 0.4] );
    else
        subplot(2,1,1);
    end
    
    makeRateHeatMap( r.rate, order, cases, hour, segID, nightID, nightLabel );
    
    if( nEps == 12 )
        xlim([1 16])
    end
    
    h = get(gca, 'xlabel');
    h.Position = [ 0.5 -0.2 0];
    
    h = ylabel('Channel Enum.');
    if( doWide )
        h.Position = [ -0.04 0.5 0];
    else
        h.Position = [ -0.1 0.5 0];
    end
    
    temp = caxis();
    temp(1) = 0;
    caxis(temp);
    
    %% W plot
    
    if( doWide )
        ax(2) = axes( 'position', [0.07 0.1 0.2 0.4] );
    else
        subplot(2,2,3);
    end
    
    makeRateHeatMap( W, order, cases, [], segID, NaN, nightLabel );
    
    if( all(isfinite(SOZ)) || all(isfinite(RV)) )
        xlim([1 K+2+doWide*0.4 ]);
    end
    
    h = ylabel('Channel Enum.');
    h.Units = 'normalized';
    h.Position = [ -0.25 0.5 0];
    
    h = colorbar;
    xlabel(h,'Arbitrary units', 'fontsize', 18);
    h.Label.Units = 'normalized';
    if( doWide )
        h.Label.Position = [2.2 0.5 0];
    else
        h.Label.Position = [2 0.5 0];
    end
    
    temp = caxis();
    temp(1) = 0;
    caxis(temp);
    
    fprintf('\tChan Grp | Channels above threshold\n');
    if( ~isempty(W) )
      for k=1:size(W,2)
        fprintf('\t%8d | %s\n', k, sprintf('%d ', find(W(flip(order),k)>thres)));
      end
    end
    
    
    %% R plot
    
    if( doWide )
        ax(3) = axes( 'position', [0.35 0.1 0.65 0.35] );
    else
        subplot(2,2,4);
    end
    
    imagesc( H );
    
    % y-axis labels
    
    h = ylabel('Chan. Group');
    h.Units = 'normalized';
    if( doWide )
        h.Position = [ -0.03 0.5 0];
    else
        h.Position = [ -0.08 0.5 0];
    end
    
    yTick = (1:K);
    yTickLabel = arrayfun(@(x) sprintf('%d', floor(x)), yTick, 'uniformoutput', false );
    set( gca, 'YTick', yTick, 'YTickLabel', yTickLabel, 'fontsize', 14 );
    
    % color bar
    
    h = colorbar('location', 'NorthOutside');
    xlabel(h,'Arbitrary units', 'fontsize', 18)
    
    temp = caxis();
    temp(1) = 0;
    caxis(temp);
    
    % x-axis labels
    
    set( gca, 'TickLength', [0 0], 'Box', 'off' );
    
    times = arrayfun( @(x,y) sprintf('%d:%02d', x, y), floor(hour),round((hour-floor(hour))*60), 'uniformoutput', false );
    
    xTick = 1;
    xTickLabel = times(1);
    
    for i=2:nEps
        if( segID(i-1) ~= segID(i) )
            line( i*[1 1]-0.5, ylim, 'color', 'w' );
            xTick = [xTick i]; %#ok<*AGROW>
            xTickLabel = [xTickLabel times(i)];
        end
        
        if( i - xTick(end) >= 3 )
            xTick = [xTick i]; %#ok<*AGROW>
            xTickLabel = [xTickLabel times(i)];
        end
    end
    
    xTick = [xTick nEps+1];
    xTickLabel = [xTickLabel times(end)];
    
    if( doWide )
        I = find(diff(xTick) > 0.01 * nEps);
        if(~I(1))
            I = [1 I];
        end
        
        xTick = xTick(I);
        xTickLabel = xTickLabel(I);
    end

    xTick = xTick + nEps*0.015;
    sz = 14;
    if( doWide )
        sz = 10;
    end
    set( gca, 'XTick', xTick, 'XTickLabel', xTickLabel, 'fontsize', sz );
    xticklabel_rotate();
    
    h = xlabel('Time of Day');
    if( doWide )
        h.Position = [ 0.5 -0.26 0];
    else
        h.Position = [ 0.5 -0.2 0];
    end
    
    set(gca, 'fontsize', 18 );
    
    %% print
    
    filename = ['plots/HFO_rate_factorized.' dbKey '.' hfoAlgo '.eps'];
    print( filename, '-depsc' );
    
end

end
