function plot_max_chan()
%% function plot_max_chan()
%
% Max HFO rate channel plot for Figure A5
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

%% prep

all_c = cell(3,4);
frac_SOZ = cell(3,4);
frac_RV = cell(3,4);

%% load data

cohort = {'Mayo','Control','UMHS-2hr','UMHS-NREM'};
hfoAlgo = {'qHFO_v2.2', 'qHFO_v2.2_FR_200', 'other-HIL'};

for kk = 1:3 % loop over HFO algos
  for k = 1:4 % loop over cohorts
    f = load(['data/' cohort{k} '.' hfoAlgo{kk} '.inputData.mat']);
    g = load(['data/' cohort{k} '.' hfoAlgo{kk} '.results.mat']);
    
    %% loop over patients
   
    n = length(f.data);
    all_c_temp = cell(n,1);
    frac_SOZ{kk,k} = NaN(1,n);
    frac_RV{kk,k} = NaN(1,n);

    outcomeCategory = zeros(1,length(f.data));

    for i=1:length(f.data)
      r = f.data(i);
      r.counts = g.results(i).counts;

      if( ~isempty(r) )
        %% parse input
        cMax = r.nChan;
        cMax = min(r.nChan, size(r.counts,1));
        [~,m] = max(r.counts(1:cMax,:));
        c = accumarray( m(:), 1 );

        if( any(isfinite( r.SOZ )) )
          frac_SOZ{kk,k}(i) = mean(r.SOZ(m));
        end
        if( any(isfinite( r.RV )) )
          frac_RV{kk,k}(i) = mean(r.RV(m));
        end
        
        all_c_temp{i} = c(c>0)'/sum(c);

        outcomeCategory(i) = r.outcomeCategory;

      end
    end

    %% reshape as needed
    all_c{kk,k} = [all_c_temp{:}];
    if( k> 2 )
      frac_RV{kk,k} = frac_RV{kk,k}(outcomeCategory==1);
    end
  end
end


%% prep figure

set(gcf, 'Renderer', 'painters', ...
    'InvertHardcopy','on',...
    'Position',[0 0 1500 800]+50,...
    'PaperPositionMode','auto');
clf

green  = [127,201,127]/255;
purple = [190,174,212]/255;
orange = [253,192,134]/255;
yellow = [255,255,153]/255;
blue   = [56,108,176]/255;
colors = {blue, yellow, purple, green};

%% plot epoch distribution

for kk=1:3
  subplot( 3, 3, (kk-1)*3+1 );

  L = arrayfun( @(i) ones(size(all_c{kk,i}))*i, 1:4, 'uniformoutput', false );
  gbar( [all_c{kk,:}], [L{:}], 10, colors, 1, [0 1] );
  
  xlim([0 1.08]);
  ylim([0 1.01]);
  xlabel('Epochs');
  ylabel('Max Chans.');
  
  h = gca;
  h.FontSize = 16;
  h.XTick = 0:0.25:1;
  h.XTickLabel = arrayfun( @(x) sprintf( '%d%%', x ), h.XTick*100, 'uniformoutput', false );

  h.YTick = 0:.5:1;
  h.YTickLabel = arrayfun( @(x) sprintf( '%d%%', x ), h.YTick*100, 'uniformoutput', false );
  
  if( kk == 1 )
    cohortNames = {'Mayo (1-3 AM)', 'Controls (1-3 AM)', 'UM (1-3 AM)', 'UM (NREM sleep)' };
    legend(cohortNames, 'fontsize', 18, 'location', 'NorthEast' );
  end
end

%% plot SOZ

for kk=1:3
  subplot( 3, 3, (kk-1)*3+2 );
  
  idx = [1 3 4];
  L = arrayfun( @(i) ones(size(frac_SOZ{kk,idx(i)}))*i, 1:3, 'uniformoutput', false );
  gbar( [frac_SOZ{kk,idx}], [L{:}], 10, colors(idx), 1 );
  
  xlim([0 1.08]);
  ylim([0 1.01]);
  xlabel('Epochs with Max Chan in SOZ');
  ylabel('Patients');

  h = gca;
  h.FontSize = 16;
  h.XTick = 0:0.25:1;
  h.XTickLabel = arrayfun( @(x) sprintf( '%d%%', x ), h.XTick*100, 'uniformoutput', false );
  
  h.YTick = 0:.25:1;
  h.YTickLabel = arrayfun( @(x) sprintf( '%d%%', x ), h.YTick*100, 'uniformoutput', false );

end

%% plot RV

for kk=1:3
  subplot( 3, 3, (kk-1)*3+3 );
  
  L = arrayfun( @(i) ones(size(frac_RV{kk,i}))*i, 3:4, 'uniformoutput', false );
  h = gbar( [frac_RV{kk,3:4}], [L{:}], 10, colors(3:4), 1 );
  for i=1:2
    h(i).EdgeColor = h(i).FaceColor;
    h(i).FaceColor = 'w';
    h(i).LineWidth = 2;
  end
  
  xlim([0 1.08]);
  ylim([0 1.01]);
  xlabel('Epochs with Max Chan in RV');
  ylabel('Patients');

  h = gca;
  h.FontSize = 16;
  h.XTick = 0:0.25:1;
  h.XTickLabel = arrayfun( @(x) sprintf( '%d%%', x ), h.XTick*100, 'uniformoutput', false );
  
  h.YTick = 0:.25:1;
  h.YTickLabel = arrayfun( @(x) sprintf( '%d%%', x ), h.YTick*100, 'uniformoutput', false );

  if( kk == 1 )
    cohortNames = {'UM (1-3 AM) [Class 1]', 'UM (NREM sleep) [Class 1]' };
    legend(cohortNames, 'fontsize', 18, 'location', 'NorthWest' );
  end

end

%% save

print(['plots/max_chan.eps'], '-depsc');
