function plot_scan_UM_rec_time( hfoAlgo )
%% function plot_scan_UM_rec_time( hfoAlgo )
%
% Plot the results for scanning over how much recording time to consider
% before making categorization.  Possible values for hfoAlgo are
% 'qHFO_v2.2', 'qHFO_v2.2_FR_200', 'other-HIL'.
%
% Created in 2016 by S. Gliske (sgliske@umich.edu)
% Released under the CC-BY-NC-4.0 License
% http://creativecommons.org/licenses/by-nc/4.0/
%

%% prep
f = load(['data/UMHS-NREM.' hfoAlgo '.inputData.mat']);
g = load(['data/UMHS-NREM.' hfoAlgo '.results.mat']);

nSubjects = length(g.results);
data   = cell(1,nSubjects);

%%
for i=1:nSubjects
  
  data{i}.labels = [];
  data{i}.frac = [];
  data{i}.hours = [];
  
  if( ~isempty(g.results(i).scan) )
    usable = cellfun( @(x) all([x.K]>0), g.results(i).scan.catResults );
    if( any(usable) )
      data{i}.labels = cellfun( @(x) -mode(-[x.label]) - 'a' + 1, g.results(i).scan.catResults(usable) )';
      data{i}.frac   = cellfun( @(x) mean( [x.label] == mode([x.label])), g.results(i).scan.catResults(usable) )';
      data{i}.hours = g.results(i).scan.allEpTimes(usable);
    end
  end
  
  %% need to add in when the recording started/stopped
  
  data{i}.startRecording = f.data(i).hfoRecordingTimes.startHour;
  data{i}.stopRecording = f.data(i).hfoRecordingTimes.stopHour;

  if( strcmp( f.data(i).dbKey, 'UMHS-0015' ) ) %% sleep scoring ended on night 6 for UMHS-0015
    data{i}.startRecording = min( data{i}.startRecording, 7*24+6 );
    data{i}.stopRecording = min( data{i}.stopRecording, 7*24+6 );

    % make sure no empty things causing trouble  
    I = data{i}.stopRecording - data{i}.startRecording > 0;
    data{i}.startRecording = data{i}.startRecording(I);
    data{i}.stopRecording = data{i}.stopRecording(I);
  end


  %% make (X,Y) for the lines
  nLines = length(data{i}.startRecording);
  data{i}.line_X = cell(nLines,1);
  data{i}.line_Y = cell(nLines,1);
  for j=1:nLines
    I = data{i}.hours > data{i}.startRecording(j) & data{i}.hours < data{i}.stopRecording(j);

    x = data{i}.hours(I);
    y = data{i}.labels(I);

    %% double to make stair-step type plot
    %x = [x; x];
    %y = [y; y];
    
    data{i}.line_X{j} = [ data{i}.startRecording(j) x(:)' data{i}.stopRecording(j) ];
    data{i}.line_Y{j} = [ 0                         y(:)'  ];

    if( j > 1 )
      data{i}.line_Y{j}(1) = data{i}.line_Y{j-1}(end);
    end
  end

end


%% prepare plot

set(gcf, 'Renderer', 'painters', ...
    'InvertHardcopy','on',...
    'Position',[0 0 1500 600]+50,...
    'PaperPositionMode','auto');
clf

green  = [127,201,127]/255;
purple = [190,174,212]/255;
orange = [253,192,134]/255;
yellow = [255,255,153]/255;
blue   = [56,108,176]/255;

colors = {green, blue, purple, yellow};
sleepColor = orange;
dayColor = [ 1 1 1];
nightColor = 0.5*[ 1 1 1];

h = gca;
h.Layer = 'top';

h4L = [];

y1 = 0;
y2 = nSubjects+1;

set(gca,'Color', dayColor );

for i=0:14  % night
    x1 = i*24+22;
    x2 = x1+8;
    
    h4L(6) = patch( [x1 x1 x2 x2], [y1 y2 y2 y1], -[1 1 1 1], 'facecolor', nightColor, 'edgecolor', nightColor );
end

minX = Inf;
maxX = 0;
for i=1:nSubjects
    
    for j=1:length(data{i}.line_X)
        
        if( isfield( data{i}, 'line_X' ) )
            for k=1:length(data{i}.line_Y{j})
                x1 = ceil(data{i}.line_X{j}(k));
                x2 = ceil(data{i}.line_X{j}(k+1));
                y1 = nSubjects + 1 - i + 0.01;
                y2 = nSubjects + 1 - i + 0.4;
                cIdx  = data{i}.line_Y{j}(k);
                
                if( cIdx == 0 )
                  h4L(cIdx+1) = patch( [x1 x1 x2 x2], [y1 y2 y2 y1], [1 1 1 1], 'facecolor', 'w', 'edgecolor', 'k', 'linewidth', 1 );
                else
                  h4L(cIdx+1) = patch( [x1 x1 x2 x2], [y1 y2 y2 y1], [1 1 1 1], 'facecolor', colors{cIdx+1}, 'edgecolor', colors{cIdx+1} );
                end
                
            end
        end
        
        minX = min( x1, minX );
        maxX = max( x2, maxX );
    end
    
    for j=1:length( f.data(i).startHour )
        x1 = f.data(i).startHour(j);
        x2 = x1 + 10/60;
        y1 = nSubjects + 1 - i - 0.01;
        y2 = nSubjects + 1 - i - 0.4;
        
        h4L(5) = patch( [x1 x1 x2 x2], [y1 y2 y2 y1], [1 1 1 1], 'facecolor', sleepColor, 'edgecolor', sleepColor );
        
        minX = min( x1, minX );
        maxX = max( x2, maxX );
        
    end
    
end

xlim([floor(minX) - 6, maxX+1]);
ylim([0 nSubjects+1]);

xTicks = 0:24:maxX;
xTicks2 = 0:6:maxX;
xTicks = xTicks( xTicks > minX );
xTicks2 = xTicks2( xTicks2 > minX );

xTickL = arrayfun( @(x) sprintf('Day %d', floor(x/24)), xTicks, 'UniformOutput', false );

set(gca,'XMinorTick','on')
set( gca, 'XTick', xTicks, 'XTickLabel', xTickL );
h = gca;
h.XRuler.MinorTickValues = xTicks2;
h.XGrid = 'off';
h.YGrid = 'off';

xTickL = cell(size(xTicks));
for i=1:length(xTicks)
  d = floor(xTicks(i)/24);
  
  if( d == xTicks(i)/24 )
    xTickL{i} = sprintf('%d', d );
  else
    xTickL{i} = sprintf(' ', d );
  end
end

set( gca, 'YTick', 1:nSubjects, 'YTickLabel', flip({f.data.dbKey}), 'fontsize', 18 );

xlabel('Time [days]');

set(gca, 'fontsize', 18 );
set( gca, 'XTick', xTicks, 'XTickLabel', xTickL );

h = gca;
h.XRuler.FontSize = 14;

set(gca,'XMinorTick','on')
hL = legend( h4L, ...
             {'< 5 epochs of interictal NREM sleep', '(a) one consistent source', '(b) one source with on/off', '(c) multiple sources on/off', 'interictal NREM sleep epoch', '10 PM to 6 AM'}, ...
             'fontsize', 18 );

set( hL, 'position', [0.7, 0.3, 0.25, 0.16] );


%% Last change

lastChangeX.cal = NaN(nSubjects,1);
lastChangeX.rec = NaN(nSubjects,1);

for i=1:nSubjects
    lastY = data{i}.line_Y{end}(end);
    for j=length(data{i}.line_Y):-1:1
        k = find(data{i}.line_Y{j} ~= lastY, 1, 'last' );
        if( ~isempty(k) )
            lastChangeX.cal(i) = data{i}.line_X{j}(k);
            lastChangeX.rec(i) = data{i}.line_X{j}(k) - f.data(i).hfoRecordingTimes.startHour(1);
            break;
        end
    end
end

fprintf('Last change in category: %.2f +/- %.2f days (max %.2f) (w.r.t. surgery day)\n', nanmean(lastChangeX.cal)/24, nanstd(lastChangeX.cal)/24/sqrt(sum(isfinite(lastChangeX.cal))), nanmax( lastChangeX.cal )/24 );
fprintf('Last change in category: %.2f +/- %.2f days (max %.2f) (w.r.t. start of recording)\n', nanmean(lastChangeX.rec)/24, nanstd(lastChangeX.rec)/24/sqrt(sum(isfinite(lastChangeX.rec))), nanmax( lastChangeX.rec )/24 );


fprintf('Last change in category: %.2f w/ %.2f days (max %.2f) (w.r.t. surgery day)\n', nanmedian(lastChangeX.cal)/24, iqr(lastChangeX.cal)/24/sqrt(sum(isfinite(lastChangeX.cal))), nanmax( lastChangeX.cal )/24 );
fprintf('Last change in category: %.2f w/ %.2f days (max %.2f) (w.r.t. start of recording)\n', nanmedian(lastChangeX.rec)/24, iqr(lastChangeX.rec)/24/sqrt(sum(isfinite(lastChangeX.rec))), nanmax( lastChangeX.rec )/24 );

print(['plots/UM_rec_scan.' hfoAlgo '.eps'],'-depsc');








